@@ -3,6 +3,9 @@ from uquake.nlloc.nlloc import *
 from uquake.core.event import (Catalog, Event, CreationInfo, Origin)
 from uquake.core import UTCDateTime
 import numpy as np
+from pydantic import BaseModel
+from ..services import models
+from typing import Optional, List
 
 
 def calculate_uncertainty(point_cloud):
@@ -40,7 +43,20 @@ def calculate_uncertainty(point_cloud):
                              confidence_level=68)
 
 
-class NLLOCResult(object):
+class Rays(BaseModel):
+    pass
+
+
+class NLLOCResult(BaseModel):
+
+    hypocenter: List[float]
+    event_time: datetime
+    scatter_cloud: List[float]
+    rays: List[Rays]
+    observations: models.nlloc.Observations
+    evaluation_mode: models.event.evaluation_mode
+    evaluation_status: models.event.evaluation_status
+
     def __init__(self, hypocenter: np.array, event_time: UTCDateTime,
                  scatter_cloud: np.ndarray, rays: list,
                  observations: Observations, evaluation_mode: str,
@@ -163,8 +179,8 @@ class NLLOCResult(object):
 
 
 class NLLOC(ProjectManager):
-    def __init__(self, base_projects_path: Path, project_name: str, network_code: str,
-                 use_srces: bool=False):
+    def __init__(self, base_projects_path: Path, project_name: str,
+                 network_code: str, use_srces: bool=False):
 
         """
         Object to control NLLoc execution and manage the required grids, inputs
@@ -219,6 +235,26 @@ class NLLOC(ProjectManager):
 
         self.settings = Settings(str(self.paths.config))
 
+    def __del__(self):
+        self.remove_run_directory()
+
+    def remove_run_directory(self):
+        for fle in self.paths.observations.glob('*'):
+            fle.unlink()
+
+        self.paths.observations.rmdir()
+
+        output_dir = self.paths.outputs
+
+        for fle in output_dir.glob('*'):
+            fle.unlink()
+        output_dir.rmdir()
+
+        for fle in self.paths.outputs.parent.glob('*'):
+            fle.unlink()
+
+        self.paths.outputs.parent.rmdir()
+
     def add_template_control(self, control=Control(message_flag=1),
                              transformation=GeographicTransformation(),
                              locsig=None, loccom=None,
@@ -351,20 +387,7 @@ class NLLOC(ProjectManager):
                         f'seconds')
 
         if delete_output_files:
-            for fle in self.paths.observations.glob('*'):
-                fle.unlink()
-            self.paths.observations.rmdir()
-
-            output_dir = self.paths.outputs
-
-            for fle in output_dir.glob('*'):
-                fle.unlink()
-            output_dir.rmdir()
-
-            for fle in self.paths.outputs.parent.glob('*'):
-                fle.unlink()
-
-            self.paths.outputs.parent.rmdir()
+            self.remove_run_directory()
 
         result = NLLOCResult(np.array([x, y, z]), t, scatters, rays,
                              observations, evaluation_mode, evaluation_status)
